@@ -1,6 +1,6 @@
 import os
 import json
-from redis import Redis
+from redis import Redis, ConnectionPool
 from redis.exceptions import ConnectionError
 from cvai_logger import hlogger
 
@@ -11,12 +11,12 @@ CACHING_HOST = os.getenv('CACHING_HOST', LOCALHOST_CACHING_HOST)
 
 DEFAULT_EXP_TIME = 2 * 60 # 2 minutes
 
-redis_client = Redis(host=CACHING_HOST, port=CACHING_PORT)
+# conn_pool = ConnectionPool()
+redis_client = Redis(host=CACHING_HOST, port=CACHING_PORT, socket_timeout=0.5)
 
 def safe_cache(func):
     def inner(**kwargs):
         try:
-            redis_client.ping()
             return func(**kwargs)
         except ConnectionError:
             hlogger.warning(f"Unable to ping redis client on {CACHING_HOST}:{CACHING_PORT}", code=None)
@@ -33,9 +33,24 @@ def set_cache(key, value, exp=DEFAULT_EXP_TIME):
 
 @safe_cache
 def get_cache(key):
-    return redis_client.get(key)
+    result = redis_client.get(key)
+    j = decode_result(result)
+    return j
 
 # multiple caches
 @safe_cache
 def get_mcache(keys):
-    return redis_client.mget(keys)
+    results = redis_client.mget(keys)
+    js = map(lambda x: decode_result(x), results)
+    return list(js)
+
+def decode_result(result):
+
+    # result not present in the DB
+    if result == None:
+        return result
+
+    string = result.decode("utf-8")
+    j = json.loads(string)
+
+    return j
